# prompt chains
![](https://img.shields.io/badge/version-v0.0.2-blue.svg)
![](https://img.shields.io/badge/python-3.9-blue.svg)
[![Docs](https://img.shields.io/badge/docs-confluence-013A97)]()
![](https://img.shields.io/badge/dev-orange.svg)



Description.



## Getting Started
Install with pip:


```sh
pip install prompt-chains
```

or from source
```sh
pip install -r requirements.txt
pip install -e .
```

## Authors

*iuiu* 

## License

This project is property of *iuiu*
